@@ -5,7 +5,7 @@ use warnings;
 
 use parent qw(Tickit::Widget);
 
-our $VERSION = '0.211';
+our $VERSION = '0.212';
 
 =head1 NAME
 
@@ -13,7 +13,7 @@ Tickit::Widget::Table - table widget with support for scrolling/paging
 
 =head1 VERSION
 
-version 0.211
+version 0.212
 
 =head1 SYNOPSIS
 
@@ -727,8 +727,8 @@ sub render_header_cell {
 	my $base_pen = $self->get_style_pen(
 		'header'
 	);
-	$rb->erase_to($def->{start}, $base_pen);
-	my ($pre, undef, $post) = align textwidth($def->{label} // ''), $def->{value}, $def->{align};
+	$rb->erase_to($def->{start}, $base_pen) if $def->{start};
+	my ($pre, undef, $post) = align textwidth($def->{label} // ''), $def->{value} // 0, $def->{align} // 0;
 	$rb->erase($pre, $base_pen) if $pre;
 	$rb->text($def->{label} // '', $base_pen);
 	$rb->erase($post, $base_pen) if $post;
@@ -828,7 +828,7 @@ sub render_row {
 		my $v = $self->apply_view_transformations($row, $col, $data->[$col]);
 		my $def = $self->{columns}[$col];
 		$rb->goto($line, $def->{start} // 0);
-		my ($pre, undef, $post) = align textwidth($v), $def->{value}, $def->{align};
+		my ($pre, undef, $post) = align textwidth($v), $def->{value} // 0, $def->{align} // 0;
 		$rb->erase($pre, $base_pen) if $pre;
 		if(blessed($v) && $v->isa('String::Tagged')) {
 			# Copy before modifying, might be overkill?
@@ -849,7 +849,8 @@ sub render_row {
 			$rb->text($v, $base_pen);
 		}
 		$rb->erase($post, $base_pen) if $post;
-		$rb->erase_to($col < $#$data ? $self->{columns}[$col + 1]->{start} : $self->body_cols, $base_pen);
+		my $target = $col < $#$data ? $self->{columns}[$col + 1]->{start} : $self->body_cols;
+		$rb->erase_to($target, $base_pen) if $target;
 	}
 }
 
